# Changelog

All notable changes to `dns_exporter` will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [v1.0.0-beta5] - 2024-02-20

### Changed
- Updated some dev and test dependencies
- Improve debug logging
- Enable proxy support for all protocols except DoT


## [v1.0.0-beta4] - 2024-02-19

### Fixed
- Update codecov GH action to silence warning in CI
- Handle errors in unit test setup better
- Wrote a real describe() method in the collector
- Support dnspython 2.6.0 as well as earlier versions
- Add ttl metrics for all rrs.
- Improve logformat used during unit tests

### Added
- Basic proxy support for plain TCP DNS lookups, supported proxy types are SOCKS4, SOCKS5 and HTTP.
- Introduced pytest-mock test dependency to help with testing proxy code
- Three new failure modes: `invalid_request_proxy`, `connection_error`, `connection_refused`


### Changed
- Suppress warnings at runtime (to silence dependencies)
- Fail with a nice message if the port is in use when starting the exporter


## [v1.0.0-beta3] - 2024-02-15

### Fixed
- DockerHub workflow unbroken, take 2


## [v1.0.0-beta2] - 2024-02-10

### Fixed
- DockerHub workflow unbroken


## [v1.0.0-beta1] - 2024-02-09

### Changed
- Update CHANGELOG
- Add more badges to README.md


## [v1.0.0-alpha1] - 2024-02-08

Version 1.0.0 is a major refactor. It changes some metric names and has many internal changes. It also enables DoQ support. Most stuff should work as it did before 1.0.0 though.

The metrics exposed under /query (per-scrape metrics) are now:
- dnsexp_dns_query_time_seconds (Gauge, unchanged)
- dnsexp_dns_query_success (Gauge, unchanged)
- dnsexp_dns_response_rr_ttl_seconds (Gauge, unchanged)
- dnsexp_failures_total (Counter, renamed and changed from Enum)

The metrics exposed under /metrics (persistent exporter-internal metrics) are now:
- dnsexp_build_version (Info, unchanged)
- dnsexp_http_requests_total (Counter, unchanged)
- dnsexp_http_responses_total (Counter, unchanged)
- dnsexp_dns_queries_total (Counter, unchanged)
- dnsexp_dns_responsetime_seconds (Histogram, renamed and changed from Counter)
- dnsexp_scrape_failures_total (Counter, renamed and got a reason label)

Further changes are mostly technical details.

### Added
- RELEASE.md file describing how to do a release
- `build` module to the `dev` extras in `pyproject.toml`
- Python 3.12 support
- Automatic DockerHub upload of containers when new releases are tagged
- Automatic PyPi upload of packages when new releases are tagged

### Changed
- Delete the `develop` branch, `main` is the new default branch. Update `RELEASE.md` to reflect the change.
- Update some development dependencies
- Major refactor: move DNS lookup to a custom `prometheus_client.registry.Collector` class in `collector.py`

### Fixed
- DNS over QUIC support now works. Default port is 853 as per https://www.rfc-editor.org/rfc/rfc9250.html#name-port-selection


## [v0.3.0] - 2024-01-25

### Changed
- Split code into seperate modules
- Rename `dnsexp_dns_time_seconds` to `dnsexp_dns_query_time_seconds` and change from Histogram to Gauge
- Rename `dnsexp_dns_success` to `dnsexp_dns_query_success`
- Rename `dnsexp_dns_failure_reason` to `dnsexp_dns_query_failure_reason`
- Rename `dnsexp_dns_record_ttl_seconds` to `dnsexp_dns_response_rr_ttl_seconds` and change from Histogram to Gauge

### Added
- Command-line option to set listen IP, use `-L` or `--listen-ip`. Default is `127.0.0.1`.
- Unit tests
- Github action to build a new dockerhub image when a new tag is pushed
- Python3.12 is now tested in CI
- Add a Dockerfile (thanks @dallemon)


## [v0.2.0] - 2023-04-12

### Changed
- Split code into multiple modules

### Added
- Write unit tests
- Write documentation

### Fixed
- Many, many bugs while writing unit tests


## [v0.2.0-beta3] - 2023-01-09

### Changed
- Removed the config file requirement
- Removed the requirement to supply a module in every scrape request
- Updated README.md with more information


## [v0.2.0-beta2] - 2023-01-08

This was the first public pre-release.

### Added

- CHANGELOG.md
- release.sh
